@@ -3,7 +3,7 @@ from haystack.query import SearchQuerySet
 
 from django.db.models import Manager
 from django.db.models import Q
-from django.contrib.auth.models import User
+from django.contrib.auth.models import User, AnonymousUser
 
 from tendenci.core.perms.managers import TendenciBaseManager
 
@@ -19,6 +19,36 @@ class GroupManager(TendenciBaseManager):
 
         return group
 
+    def get_or_create_default(self, user=AnonymousUser()):
+        from tendenci.apps.entities.models import Entity
+        from tendenci.core.site_settings.utils import get_global_setting
+        group = self.first()
+        if not group:
+            entity = Entity.objects.first()
+            if not entity:
+                entity = Entity.objects.get_or_create_default(user)
+            params = {'name': get_global_setting('sitedisplayname'),
+                  'entity': entity,
+                  'type': 'distribution',
+                  'email_recipient': get_global_setting('sitecontactemail'),
+                  'allow_anonymous_view': True,
+                  'status': True,
+                  'status_detail': 'active'
+                  }
+            if not user.is_anonymous():
+                params.update({'creator': user,
+                               'creator_username': user.username,
+                               'owner': user,
+                               'owner_username': user.username
+                               })
+            else:
+                params.update({'creator_username': '',
+                               'owner_username': ''
+                               })
+            group = self.create(**params)
+
+        return group
+
 
 class OldGroupManager(Manager):
     def search(self, query=None, *args, **kwargs):
